The alkymi API
==============

Decorators
----------
.. automodule:: alkymi.decorators
    :members:

Recipe
------
.. automodule:: alkymi.recipe
    :members:

.. _foreach_recipe:

ForeachRecipe
-------------
.. automodule:: alkymi.foreach_recipe
    :members:

.. _checksums_api:

Checksums
---------
.. automodule:: alkymi.checksums
    :members:

.. _serialization:

Serialization
-------------
.. automodule:: alkymi.serialization
    :members:

.. _lab:

Lab
---
.. automodule:: alkymi.lab
    :members:

.. _built_in_recipes_api:

Built-in Recipes
----------------
.. automodule:: alkymi.recipes
    :members:

Core
----
.. automodule:: alkymi.alkymi
    :members:

.. _alkymi_config:

AlkymiConfig
------------

.. automodule:: alkymi.config
    :members:
